==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MappingDataFlowArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Mapping data flow.
 * @property annotations List of tags that can be used for describing the data flow.
 * @property description The description of the data flow.
 * @property folder The folder that this data flow is in. If not specified, Data flow will appear at the root level.
 * @property script DataFlow script.
 * @property scriptLines Data flow script lines.
 * @property sinks List of sinks in data flow.
 * @property sources List of sources in data flow.
 * @property transformations List of transformations in data flow.
 * @property type Type of data flow.
 * Expected value is 'MappingDataFlow'.
 */
public data class MappingDataFlowArgs(
    public val annotations: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val folder: Output<DataFlowFolderArgs>? = null,
    public val script: Output<String>? = null,
    public val scriptLines: Output<List<String>>? = null,
    public val sinks: Output<List<DataFlowSinkArgs>>? = null,
    public val sources: Output<List<DataFlowSourceArgs>>? = null,
    public val transformations: Output<List<TransformationArgs>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs =
        com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .folder(folder?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .script(script?.applyValue({ args0 -> args0 }))
            .scriptLines(scriptLines?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sinks(sinks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .sources(
                sources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .transformations(
                transformations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MappingDataFlowArgs].
 */
@PulumiTagMarker
public class MappingDataFlowArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var folder: Output<DataFlowFolderArgs>? = null

    private var script: Output<String>? = null

    private var scriptLines: Output<List<String>>? = null

    private var sinks: Output<List<DataFlowSinkArgs>>? = null

    private var sources: Output<List<DataFlowSourceArgs>>? = null

    private var transformations: Output<List<TransformationArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("kasxvmnmwhmrepll")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("tlvcabrgdkaugsug")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("lkgeahavxgfpdqai")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("plexydkxalotfkkm")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("exysxtpjqpbcufot")
    public suspend fun folder(`value`: Output<DataFlowFolderArgs>) {
        this.folder = value
    }

    /**
     * @param value DataFlow script.
     */
    @JvmName("vfodowuifckoqxas")
    public suspend fun script(`value`: Output<String>) {
        this.script = value
    }

    /**
     * @param value Data flow script lines.
     */
    @JvmName("kchhvfvtabgswmnv")
    public suspend fun scriptLines(`value`: Output<List<String>>) {
        this.scriptLines = value
    }

    @JvmName("ojlvenlyjobpppto")
    public suspend fun scriptLines(vararg values: Output<String>) {
        this.scriptLines = Output.all(values.asList())
    }

    /**
     * @param values Data flow script lines.
     */
    @JvmName("gphnglrtbdnnfmio")
    public suspend fun scriptLines(values: List<Output<String>>) {
        this.scriptLines = Output.all(values)
    }

    /**
     * @param value List of sinks in data flow.
     */
    @JvmName("dubviuwkngiyjxvi")
    public suspend fun sinks(`value`: Output<List<DataFlowSinkArgs>>) {
        this.sinks = value
    }

    @JvmName("bsxqhxllfduvasfp")
    public suspend fun sinks(vararg values: Output<DataFlowSinkArgs>) {
        this.sinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks in data flow.
     */
    @JvmName("losvocxdwhkyfemt")
    public suspend fun sinks(values: List<Output<DataFlowSinkArgs>>) {
        this.sinks = Output.all(values)
    }

    /**
     * @param value List of sources in data flow.
     */
    @JvmName("wyhuttjchujkvvrr")
    public suspend fun sources(`value`: Output<List<DataFlowSourceArgs>>) {
        this.sources = value
    }

    @JvmName("jsbrudvyhrdsaakv")
    public suspend fun sources(vararg values: Output<DataFlowSourceArgs>) {
        this.sources = Output.all(values.asList())
    }

    /**
     * @param values List of sources in data flow.
     */
    @JvmName("bijafhcnqyvgddtp")
    public suspend fun sources(values: List<Output<DataFlowSourceArgs>>) {
        this.sources = Output.all(values)
    }

    /**
     * @param value List of transformations in data flow.
     */
    @JvmName("oxejkreetryehqku")
    public suspend fun transformations(`value`: Output<List<TransformationArgs>>) {
        this.transformations = value
    }

    @JvmName("hjeraqhsgnekbuhh")
    public suspend fun transformations(vararg values: Output<TransformationArgs>) {
        this.transformations = Output.all(values.asList())
    }

    /**
     * @param values List of transformations in data flow.
     */
    @JvmName("kqredfvrniuiholt")
    public suspend fun transformations(values: List<Output<TransformationArgs>>) {
        this.transformations = Output.all(values)
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'MappingDataFlow'.
     */
    @JvmName("frlwxygalhuqolvp")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("cmrtbucvhsrvxikt")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("mkemxnwoweaisque")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("gwuqhpnjfqscipsr")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("kuaflvgvivtmawpa")
    public suspend fun folder(`value`: DataFlowFolderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folder = mapped
    }

    /**
     * @param argument The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("llapoeenoipojyov")
    public suspend fun folder(argument: suspend DataFlowFolderArgsBuilder.() -> Unit) {
        val toBeMapped = DataFlowFolderArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.folder = mapped
    }

    /**
     * @param value DataFlow script.
     */
    @JvmName("wtsexwwfpjmrvyhx")
    public suspend fun script(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.script = mapped
    }

    /**
     * @param value Data flow script lines.
     */
    @JvmName("ovipmwxwmfyhmwmm")
    public suspend fun scriptLines(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param values Data flow script lines.
     */
    @JvmName("rwctpydvtgiqwvln")
    public suspend fun scriptLines(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param value List of sinks in data flow.
     */
    @JvmName("wrjrwqdxthdejhnl")
    public suspend fun sinks(`value`: List<DataFlowSinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("mrxwrwdpbemgnldo")
    public suspend fun sinks(argument: List<suspend DataFlowSinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("ehdhrcfivoyonpja")
    public suspend fun sinks(vararg argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("umxgxvqifnwsqsjr")
    public suspend fun sinks(argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param values List of sinks in data flow.
     */
    @JvmName("ssalstfsxyuunfam")
    public suspend fun sinks(vararg values: DataFlowSinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param value List of sources in data flow.
     */
    @JvmName("kvwyvajvlndgsxqd")
    public suspend fun sources(`value`: List<DataFlowSourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("pfkvvbtbnjmeyctj")
    public suspend fun sources(argument: List<suspend DataFlowSourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("hqcdvsyfllsudcjh")
    public suspend fun sources(vararg argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("xsxvutnbaaklwmaa")
    public suspend fun sources(argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param values List of sources in data flow.
     */
    @JvmName("bthrgswtufbtvayc")
    public suspend fun sources(vararg values: DataFlowSourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param value List of transformations in data flow.
     */
    @JvmName("fbukmcjtjyppodlk")
    public suspend fun transformations(`value`: List<TransformationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("icklgliivxcwumta")
    public suspend fun transformations(argument: List<suspend TransformationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("kpddvdyouhsdydlw")
    public suspend fun transformations(
        vararg
        argument: suspend TransformationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("lxvspnxmancyhbng")
    public suspend fun transformations(argument: suspend TransformationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TransformationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param values List of transformations in data flow.
     */
    @JvmName("txudpddaeymkiwqp")
    public suspend fun transformations(vararg values: TransformationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'MappingDataFlow'.
     */
    @JvmName("yatoouvarqqcduyj")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): MappingDataFlowArgs = MappingDataFlowArgs(
        annotations = annotations,
        description = description,
        folder = folder,
        script = script,
        scriptLines = scriptLines,
        sinks = sinks,
        sources = sources,
        transformations = transformations,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MappingDataFlowArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Mapping data flow.
 * @property annotations List of tags that can be used for describing the data flow.
 * @property description The description of the data flow.
 * @property folder The folder that this data flow is in. If not specified, Data flow will appear at the root level.
 * @property script DataFlow script.
 * @property scriptLines Data flow script lines.
 * @property sinks List of sinks in data flow.
 * @property sources List of sources in data flow.
 * @property transformations List of transformations in data flow.
 * @property type Type of data flow.
 * Expected value is 'MappingDataFlow'.
 */
public data class MappingDataFlowArgs(
    public val annotations: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val folder: Output<DataFlowFolderArgs>? = null,
    public val script: Output<String>? = null,
    public val scriptLines: Output<List<String>>? = null,
    public val sinks: Output<List<DataFlowSinkArgs>>? = null,
    public val sources: Output<List<DataFlowSourceArgs>>? = null,
    public val transformations: Output<List<TransformationArgs>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs =
        com.pulumi.azurenative.datafactory.inputs.MappingDataFlowArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .folder(folder?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .script(script?.applyValue({ args0 -> args0 }))
            .scriptLines(scriptLines?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sinks(sinks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .sources(
                sources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .transformations(
                transformations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MappingDataFlowArgs].
 */
@PulumiTagMarker
public class MappingDataFlowArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var folder: Output<DataFlowFolderArgs>? = null

    private var script: Output<String>? = null

    private var scriptLines: Output<List<String>>? = null

    private var sinks: Output<List<DataFlowSinkArgs>>? = null

    private var sources: Output<List<DataFlowSourceArgs>>? = null

    private var transformations: Output<List<TransformationArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("bqlyifdwvajtmlbt")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("okqigqymutreybni")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("hbwurpejfdojeqkr")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("thrxrhxxridebsmf")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("fbqcamjtriqyvyqd")
    public suspend fun folder(`value`: Output<DataFlowFolderArgs>) {
        this.folder = value
    }

    /**
     * @param value DataFlow script.
     */
    @JvmName("lefxcntkagwctwyj")
    public suspend fun script(`value`: Output<String>) {
        this.script = value
    }

    /**
     * @param value Data flow script lines.
     */
    @JvmName("ywphsinjlstvlejt")
    public suspend fun scriptLines(`value`: Output<List<String>>) {
        this.scriptLines = value
    }

    @JvmName("eeogykmpnicnywlh")
    public suspend fun scriptLines(vararg values: Output<String>) {
        this.scriptLines = Output.all(values.asList())
    }

    /**
     * @param values Data flow script lines.
     */
    @JvmName("pkcirrepcvjpuskh")
    public suspend fun scriptLines(values: List<Output<String>>) {
        this.scriptLines = Output.all(values)
    }

    /**
     * @param value List of sinks in data flow.
     */
    @JvmName("ooxvmnxmnsqpdhqo")
    public suspend fun sinks(`value`: Output<List<DataFlowSinkArgs>>) {
        this.sinks = value
    }

    @JvmName("pqqtgtsstaoqqlmb")
    public suspend fun sinks(vararg values: Output<DataFlowSinkArgs>) {
        this.sinks = Output.all(values.asList())
    }

    /**
     * @param values List of sinks in data flow.
     */
    @JvmName("jrmaajmhlgphcnuw")
    public suspend fun sinks(values: List<Output<DataFlowSinkArgs>>) {
        this.sinks = Output.all(values)
    }

    /**
     * @param value List of sources in data flow.
     */
    @JvmName("sjwxwtpaoainbpcd")
    public suspend fun sources(`value`: Output<List<DataFlowSourceArgs>>) {
        this.sources = value
    }

    @JvmName("gutuorodoguokwmv")
    public suspend fun sources(vararg values: Output<DataFlowSourceArgs>) {
        this.sources = Output.all(values.asList())
    }

    /**
     * @param values List of sources in data flow.
     */
    @JvmName("hqikihwpwcldgcyo")
    public suspend fun sources(values: List<Output<DataFlowSourceArgs>>) {
        this.sources = Output.all(values)
    }

    /**
     * @param value List of transformations in data flow.
     */
    @JvmName("djehinyiftlkumjl")
    public suspend fun transformations(`value`: Output<List<TransformationArgs>>) {
        this.transformations = value
    }

    @JvmName("qxrvlttmidqdykpq")
    public suspend fun transformations(vararg values: Output<TransformationArgs>) {
        this.transformations = Output.all(values.asList())
    }

    /**
     * @param values List of transformations in data flow.
     */
    @JvmName("esyjrnwvewobqrve")
    public suspend fun transformations(values: List<Output<TransformationArgs>>) {
        this.transformations = Output.all(values)
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'MappingDataFlow'.
     */
    @JvmName("bwuuevhormyfhxft")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the data flow.
     */
    @JvmName("wlaeknjpvhujqcot")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the data flow.
     */
    @JvmName("nlkkqmkqwoidsubo")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value The description of the data flow.
     */
    @JvmName("oqdriemvchpixquj")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("berbcoypawekilpx")
    public suspend fun folder(`value`: DataFlowFolderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.folder = mapped
    }

    /**
     * @param argument The folder that this data flow is in. If not specified, Data flow will appear at the root level.
     */
    @JvmName("hcbmrfacjebsvwep")
    public suspend fun folder(argument: suspend DataFlowFolderArgsBuilder.() -> Unit) {
        val toBeMapped = DataFlowFolderArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.folder = mapped
    }

    /**
     * @param value DataFlow script.
     */
    @JvmName("cptshwiatprntytl")
    public suspend fun script(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.script = mapped
    }

    /**
     * @param value Data flow script lines.
     */
    @JvmName("mlggvxijiulbwhor")
    public suspend fun scriptLines(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param values Data flow script lines.
     */
    @JvmName("sahrgkpffjwpewnk")
    public suspend fun scriptLines(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptLines = mapped
    }

    /**
     * @param value List of sinks in data flow.
     */
    @JvmName("wrapyrcysidfsdpw")
    public suspend fun sinks(`value`: List<DataFlowSinkArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("lacdhvmlhxoedquf")
    public suspend fun sinks(argument: List<suspend DataFlowSinkArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("fxbiuaeftywnypwd")
    public suspend fun sinks(vararg argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSinkArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param argument List of sinks in data flow.
     */
    @JvmName("ytpbnwylfvpyfkbq")
    public suspend fun sinks(argument: suspend DataFlowSinkArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSinkArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sinks = mapped
    }

    /**
     * @param values List of sinks in data flow.
     */
    @JvmName("roxlqvymnvqqkhkl")
    public suspend fun sinks(vararg values: DataFlowSinkArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sinks = mapped
    }

    /**
     * @param value List of sources in data flow.
     */
    @JvmName("duxdstrjprahgqim")
    public suspend fun sources(`value`: List<DataFlowSourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("sokrfjciqvonlkdu")
    public suspend fun sources(argument: List<suspend DataFlowSourceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("qpmuvnrediohqdqr")
    public suspend fun sources(vararg argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DataFlowSourceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param argument List of sources in data flow.
     */
    @JvmName("tylxmwxkadqsvaig")
    public suspend fun sources(argument: suspend DataFlowSourceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataFlowSourceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sources = mapped
    }

    /**
     * @param values List of sources in data flow.
     */
    @JvmName("bxlbbdtusowlcdpe")
    public suspend fun sources(vararg values: DataFlowSourceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sources = mapped
    }

    /**
     * @param value List of transformations in data flow.
     */
    @JvmName("xvrxvyugmkqswbox")
    public suspend fun transformations(`value`: List<TransformationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("pjwldkaynsgjuqkp")
    public suspend fun transformations(argument: List<suspend TransformationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("cteoxqarrxggjubu")
    public suspend fun transformations(
        vararg
        argument: suspend TransformationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TransformationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param argument List of transformations in data flow.
     */
    @JvmName("anujrrqsqwjldbgh")
    public suspend fun transformations(argument: suspend TransformationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TransformationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.transformations = mapped
    }

    /**
     * @param values List of transformations in data flow.
     */
    @JvmName("satywesyroferfas")
    public suspend fun transformations(vararg values: TransformationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transformations = mapped
    }

    /**
     * @param value Type of data flow.
     * Expected value is 'MappingDataFlow'.
     */
    @JvmName("qpcmwfdceesaacqh")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): MappingDataFlowArgs = MappingDataFlowArgs(
        annotations = annotations,
        description = description,
        folder = folder,
        script = script,
        scriptLines = scriptLines,
        sinks = sinks,
        sources = sources,
        transformations = transformations,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
